Mujoco

Struct Mujoco 

pub struct Mujoco { /* private fields */ }
The container that holds and runs the simulation

Implementations

Source

impl Mujoco

pub fn new(model: MjModel) -> Self

Examples found in repository?
examples/basic.rs (line 20)
18fn main() {
19    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
20    let mut mujoco = evomujoco::Mujoco::new(model);
21
22    loop {
23        mujoco.update();
24    }
25}
More examples
Hide additional examples
examples/actuator.rs (line 33)
31fn main() {
32    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33    let mut mujoco = evomujoco::Mujoco::new(model);
34
35    let act = mujoco.get_actuator("j_ctrl".to_string());
36    let joint = mujoco.get_joint_from_name("joint".to_string());
37
38    let start = SystemTime::now();
39
40    loop {
41        act.set_ctrl(f64::sin(
42            SystemTime::now()
43                .duration_since(start)
44                .unwrap()
45                .as_secs_f64(),
46        ));
47        match joint.get_qpos() {
48            evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49            _ => {}
50        }
51        mujoco.update();
52    }
53}
pub fn get_joints(&self) -> HashMap<String, Joint>

Gets all joints.

pub fn get_joint_ids(&self) -> Vec<i32>

Gets all existing joint ids.

pub fn get_joint_name(&self, index: usize) -> String

Given a joint id, this function will return the name of a joint.

pub fn get_index(&self, name: String) -> u32

Not implemented

pub fn get_joint_from_name(&self, name: String) -> Joint

Examples found in repository?
examples/actuator.rs (line 36)
31fn main() {
32    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33    let mut mujoco = evomujoco::Mujoco::new(model);
34
35    let act = mujoco.get_actuator("j_ctrl".to_string());
36    let joint = mujoco.get_joint_from_name("joint".to_string());
37
38    let start = SystemTime::now();
39
40    loop {
41        act.set_ctrl(f64::sin(
42            SystemTime::now()
43                .duration_since(start)
44                .unwrap()
45                .as_secs_f64(),
46        ));
47        match joint.get_qpos() {
48            evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49            _ => {}
50        }
51        mujoco.update();
52    }
53}
pub fn get_joint(&self, index: usize) -> Joint

Reterives a joint given a joint index.

pub fn get_actuator(&self, name: String) -> Actuator

Gets an actuator

Examples found in repository?
examples/actuator.rs (line 35)
31fn main() {
32    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33    let mut mujoco = evomujoco::Mujoco::new(model);
34
35    let act = mujoco.get_actuator("j_ctrl".to_string());
36    let joint = mujoco.get_joint_from_name("joint".to_string());
37
38    let start = SystemTime::now();
39
40    loop {
41        act.set_ctrl(f64::sin(
42            SystemTime::now()
43                .duration_since(start)
44                .unwrap()
45                .as_secs_f64(),
46        ));
47        match joint.get_qpos() {
48            evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49            _ => {}
50        }
51        mujoco.update();
52    }
53}
pub fn get_camera(&self, name: String, resolution: (u32, u32)) -> Camera

Gets a camera

pub fn update(&mut self)

The main update function. This will step the simulation and update the viewer.

Examples found in repository?
examples/basic.rs (line 23)
18fn main() {
19    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
20    let mut mujoco = evomujoco::Mujoco::new(model);
21
22    loop {
23        mujoco.update();
24    }
25}
More examples
Hide additional examples
examples/actuator.rs (line 51)
31fn main() {
32    let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33    let mut mujoco = evomujoco::Mujoco::new(model);
34
35    let act = mujoco.get_actuator("j_ctrl".to_string());
36    let joint = mujoco.get_joint_from_name("joint".to_string());
37
38    let start = SystemTime::now();
39
40    loop {
41        act.set_ctrl(f64::sin(
42            SystemTime::now()
43                .duration_since(start)
44                .unwrap()
45                .as_secs_f64(),
46        ));
47        match joint.get_qpos() {
48            evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49            _ => {}
50        }
51        mujoco.update();
52    }
53}