pub struct Mujoco { /* private fields */ }Expand description
The container that holds and runs the simulation
Implementations
Sourceimpl Mujoco
impl Mujoco
Sourcepub fn new(model: MjModel) -> Self
pub fn new(model: MjModel) -> Self
Examples found in repository?
More examples
examples/actuator.rs (line 33)
31fn main() {
32 let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33 let mut mujoco = evomujoco::Mujoco::new(model);
34
35 let act = mujoco.get_actuator("j_ctrl".to_string());
36 let joint = mujoco.get_joint_from_name("joint".to_string());
37
38 let start = SystemTime::now();
39
40 loop {
41 act.set_ctrl(f64::sin(
42 SystemTime::now()
43 .duration_since(start)
44 .unwrap()
45 .as_secs_f64(),
46 ));
47 match joint.get_qpos() {
48 evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49 _ => {}
50 }
51 mujoco.update();
52 }
53}Sourcepub fn get_joints(&self) -> HashMap<String, Joint>
pub fn get_joints(&self) -> HashMap<String, Joint>
Gets all joints.
Sourcepub fn get_joint_ids(&self) -> Vec<i32>
pub fn get_joint_ids(&self) -> Vec<i32>
Gets all existing joint ids.
Sourcepub fn get_joint_name(&self, index: usize) -> String
pub fn get_joint_name(&self, index: usize) -> String
Given a joint id, this function will return the name of a joint.
Sourcepub fn get_joint_from_name(&self, name: String) -> Joint
pub fn get_joint_from_name(&self, name: String) -> Joint
Examples found in repository?
examples/actuator.rs (line 36)
31fn main() {
32 let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33 let mut mujoco = evomujoco::Mujoco::new(model);
34
35 let act = mujoco.get_actuator("j_ctrl".to_string());
36 let joint = mujoco.get_joint_from_name("joint".to_string());
37
38 let start = SystemTime::now();
39
40 loop {
41 act.set_ctrl(f64::sin(
42 SystemTime::now()
43 .duration_since(start)
44 .unwrap()
45 .as_secs_f64(),
46 ));
47 match joint.get_qpos() {
48 evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49 _ => {}
50 }
51 mujoco.update();
52 }
53}Sourcepub fn get_actuator(&self, name: String) -> Actuator
pub fn get_actuator(&self, name: String) -> Actuator
Gets an actuator
Examples found in repository?
examples/actuator.rs (line 35)
31fn main() {
32 let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33 let mut mujoco = evomujoco::Mujoco::new(model);
34
35 let act = mujoco.get_actuator("j_ctrl".to_string());
36 let joint = mujoco.get_joint_from_name("joint".to_string());
37
38 let start = SystemTime::now();
39
40 loop {
41 act.set_ctrl(f64::sin(
42 SystemTime::now()
43 .duration_since(start)
44 .unwrap()
45 .as_secs_f64(),
46 ));
47 match joint.get_qpos() {
48 evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49 _ => {}
50 }
51 mujoco.update();
52 }
53}Sourcepub fn update(&mut self)
pub fn update(&mut self)
The main update function. This will step the simulation and update the viewer.
Examples found in repository?
More examples
examples/actuator.rs (line 51)
31fn main() {
32 let model = evomujoco::MjModel::from_xml_string(EXAMPLE).unwrap();
33 let mut mujoco = evomujoco::Mujoco::new(model);
34
35 let act = mujoco.get_actuator("j_ctrl".to_string());
36 let joint = mujoco.get_joint_from_name("joint".to_string());
37
38 let start = SystemTime::now();
39
40 loop {
41 act.set_ctrl(f64::sin(
42 SystemTime::now()
43 .duration_since(start)
44 .unwrap()
45 .as_secs_f64(),
46 ));
47 match joint.get_qpos() {
48 evomujoco::JointOutput::Hinge(j) => println!("{}", j.angle()),
49 _ => {}
50 }
51 mujoco.update();
52 }
53}Auto Trait Implementations
impl !Freeze for Mujoco
impl !RefUnwindSafe for Mujoco
impl !Send for Mujoco
impl !Sync for Mujoco
impl Unpin for Mujoco
impl !UnwindSafe for Mujoco